
import {
  select,
  selectAll,
  json,
  tsv,
  geoPath,
  geoNaturalEarth1,
  zoom,
  event,
} from 'd3';


import { feature } from 'topojson';

const svg = select('svg');

const projection = geoNaturalEarth1();
const pathGenerator = geoPath().projection(projection);



const g = svg.append('g');


g.append('path')
    .attr('class', 'sphere')
    .attr('d', pathGenerator({type: 'Sphere'}));

svg.call(zoom().on('zoom', () => {
  g.attr('transform', event.transform);
}));

Promise.all([
  tsv('https://unpkg.com/world-atlas@1.1.4/world/50m.tsv'),
  json('https://unpkg.com/world-atlas@1.1.4/world/50m.json')
]).then(([tsvData, topoJSONdata]) => {
  
  const countryName = tsvData.reduce((accumulator, d) => {
    accumulator[d.iso_n3] = d.name;
    return accumulator;
  }, {});
  
  const countries = feature(topoJSONdata, topoJSONdata.objects.countries);
  
  g.selectAll('path').data(countries.features)
    .enter().append('path')
      .attr('class', 'country')
      .attr('d', pathGenerator)
      // add the click event for selecting and deselecting 
    	.on("click",function(d){
      		var countryColor = d3.select(this).style("fill");
      		if(countryColor!= .countrySelected-fill) {
              d3.select(this).style("fill",.countrySelected-fill)
              .style('stroke', .countrySelected-stroke)
              .style('stroke-width', .countrySelected-stroke-width)
              select('.selectedName').text(countryName[d.id]);
            } else{
              d3.select(this)
              .style("fill",.country-fill)
              .style('stroke', .country-stroke)
              .style('stroke-width', .country-stroke-width); 
                  }
       });  
});



